# -*- coding: utf-8 -*-

from simmate.workflow_engine import s3task_to_workflow
from simmate.calculators.vasp.tasks.relaxation import (
    Quality02Relaxation as Quality02RelaxationTask,
)
from simmate.calculators.vasp.database.relaxation import (
    Quality02Relaxation as Quality02RelaxationResults,
)

workflow = s3task_to_workflow(
    name="relaxation/quality02",
    module=__name__,
    project_name="Simmate-Relaxation",
    s3task=Quality02RelaxationTask,
    calculation_table=Quality02RelaxationResults,
    register_kwargs=["prefect_flow_run_id", "structure", "source"],
    description_doc_short="low-quality settings meant for highly unreasonable structures",
)



# -*- coding: utf-8 -*-

"""
Calculate and plot the density of states (DOS) for a given crystal structure
"""

# TODO: when I add more calculators, I can do something like this...
# if "simmate.calculators.vasp" in installed_apps:

from simmate.calculators.vasp.workflows.density_of_states import (
    workflow as matproj_workflow,
)



# -*- coding: utf-8 -*-

from .files import (
    get_directory,
    make_archive,
    make_error_archive,
    archive_old_runs,
    empty_directory,
)
from .other import get_conda_env, get_doc_from_readme, get_chemical_subsystems

# must be last to prevent circular import
__doc__ = get_doc_from_readme(__file__)



# -*- coding: utf-8 -*-

"""
Workflows for relaxing a crystal structure
"""

# TODO: when I add more calculators, I can do something like this...
# if "simmate.calculators.vasp" in installed_apps:
from simmate.calculators.vasp.workflows.relaxation import (
    mit_workflow,
    matproj_workflow,
    quality00_workflow,
    quality01_workflow,
    quality02_workflow,
    quality03_workflow,
    quality04_workflow,
    staged_workflow,
    neb_endpoint_workflow,
)
